@@ -1,5 +1,5 @@
 
-from kraken_html.html_bootstrap import Html_bootstrap as HTML
+from kraken_html.html_bootstrap import Html_bootstrap as HTMLBOOT
 from kraken_html.kraken_record_html import Kraken_record_html as KR_HTML
 
 import json
@@ -39,7 +39,7 @@ class Kraken_html:
         self.footer_nav = footer_nav
         self.logo = logo
 
-        self.html = HTML(self.title, self.description, self.nav, self.footer_nav, self.logo)
+        self.html = HTMLBOOT(self.title, self.description, self.nav, self.footer_nav, self.logo)
 
         """
         config_file = {
@@ -75,7 +75,7 @@ class Kraken_html:
         self.logo = config_record.get('logo', ''),
         self.read_db = config_record.get('read_db', '')
 
-        self.html = HTML(self.title, self.description, self.nav, self.footer_nav, self.logo)
+        self.html = HTMLBOOT(self.title, self.description, self.nav, self.footer_nav, self.logo)
         
     def get_db_record(self, record_type, record_id):
         # Retrieves a record from kraken db
